==> knative-model-6.8.0-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1/AddressStatusFluent.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AddressStatusFluent<A extends AddressStatusFluent<A>> extends BaseFluent<A>{
  public AddressStatusFluent() {
  }
  public AddressStatusFluent(AddressStatus instance) {
    instance = (instance != null ? instance : new AddressStatus());

    if (instance != null) {
      this.withAddress(instance.getAddress());
      this.withAddresses(instance.getAddresses());
      this.withAddress(instance.getAddress());
      this.withAddresses(instance.getAddresses());
    }
  }
  private AddressableBuilder address;
  private ArrayList<AddressableBuilder> addresses = new ArrayList<AddressableBuilder>();
  public Addressable buildAddress() {
    return this.address!=null ?this.address.build():null;
  }
  public A withAddress(Addressable address) {
    _visitables.get("address").remove(this.address);
    if (address!=null){ this.address= new AddressableBuilder(address); _visitables.get("address").add(this.address);} else { this.address = null; _visitables.get("address").remove(this.address); } return (A) this;
  }
  public boolean hasAddress() {
    return this.address != null;
  }
  public A withNewAddress(String cACerts,String name,String url) {
    return (A)withAddress(new Addressable(cACerts, name, url));
  }
  public AddressNested<A> withNewAddress() {
    return new AddressNested(null);
  }
  public AddressNested<A> withNewAddressLike(Addressable item) {
    return new AddressNested(item);
  }
  public AddressNested<A> editAddress() {
    return withNewAddressLike(java.util.Optional.ofNullable(buildAddress()).orElse(null));
  }
  public AddressNested<A> editOrNewAddress() {
    return withNewAddressLike(java.util.Optional.ofNullable(buildAddress()).orElse(new AddressableBuilder().build()));
  }
  public AddressNested<A> editOrNewAddressLike(Addressable item) {
    return withNewAddressLike(java.util.Optional.ofNullable(buildAddress()).orElse(item));
  }
  public A addToAddresses(int index,Addressable item) {
    if (this.addresses == null) {this.addresses = new ArrayList<AddressableBuilder>();}
    AddressableBuilder builder = new AddressableBuilder(item);
    if (index < 0 || index >= addresses.size()) { _visitables.get("addresses").add(builder); addresses.add(builder); } else { _visitables.get("addresses").add(index, builder); addresses.add(index, builder);}
    return (A)this;
  }
  public A setToAddresses(int index,Addressable item) {
    if (this.addresses == null) {this.addresses = new ArrayList<AddressableBuilder>();}
    AddressableBuilder builder = new AddressableBuilder(item);
    if (index < 0 || index >= addresses.size()) { _visitables.get("addresses").add(builder); addresses.add(builder); } else { _visitables.get("addresses").set(index, builder); addresses.set(index, builder);}
    return (A)this;
  }
  public A addToAddresses(io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable... items) {
    if (this.addresses == null) {this.addresses = new ArrayList<AddressableBuilder>();}
    for (Addressable item : items) {AddressableBuilder builder = new AddressableBuilder(item);_visitables.get("addresses").add(builder);this.addresses.add(builder);} return (A)this;
  }
  public A addAllToAddresses(Collection<Addressable> items) {
    if (this.addresses == null) {this.addresses = new ArrayList<AddressableBuilder>();}
    for (Addressable item : items) {AddressableBuilder builder = new AddressableBuilder(item);_visitables.get("addresses").add(builder);this.addresses.add(builder);} return (A)this;
  }
  public A removeFromAddresses(io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable... items) {
    if (this.addresses == null) return (A)this;
    for (Addressable item : items) {AddressableBuilder builder = new AddressableBuilder(item);_visitables.get("addresses").remove(builder); this.addresses.remove(builder);} return (A)this;
  }
  public A removeAllFromAddresses(Collection<Addressable> items) {
    if (this.addresses == null) return (A)this;
    for (Addressable item : items) {AddressableBuilder builder = new AddressableBuilder(item);_visitables.get("addresses").remove(builder); this.addresses.remove(builder);} return (A)this;
  }
  public A removeMatchingFromAddresses(Predicate<AddressableBuilder> predicate) {
    if (addresses == null) return (A) this;
    final Iterator<AddressableBuilder> each = addresses.iterator();
    final List visitables = _visitables.get("addresses");
    while (each.hasNext()) {
      AddressableBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  public List<Addressable> buildAddresses() {
    return addresses != null ? build(addresses) : null;
  }
  public Addressable buildAddress(int index) {
    return this.addresses.get(index).build();
  }
  public Addressable buildFirstAddress() {
    return this.addresses.get(0).build();
  }
  public Addressable buildLastAddress() {
    return this.addresses.get(addresses.size() - 1).build();
  }
  public Addressable buildMatchingAddress(Predicate<AddressableBuilder> predicate) {
    for (AddressableBuilder item: addresses) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public boolean hasMatchingAddress(Predicate<AddressableBuilder> predicate) {
    for (AddressableBuilder item: addresses) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withAddresses(List<Addressable> addresses) {
    if (this.addresses != null) { _visitables.get("addresses").clear();}
    if (addresses != null) {this.addresses = new ArrayList(); for (Addressable item : addresses){this.addToAddresses(item);}} else { this.addresses = null;} return (A) this;
  }
  public A withAddresses(io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable... addresses) {
    if (this.addresses != null) {this.addresses.clear(); _visitables.remove("addresses"); }
    if (addresses != null) {for (Addressable item :addresses){ this.addToAddresses(item);}} return (A) this;
  }
  public boolean hasAddresses() {
    return addresses != null && !addresses.isEmpty();
  }
  public A addNewAddress(String cACerts,String name,String url) {
    return (A)addToAddresses(new Addressable(cACerts, name, url));
  }
  public AddressesNested<A> addNewAddress() {
    return new AddressesNested(-1, null);
  }
  public AddressesNested<A> addNewAddressLike(Addressable item) {
    return new AddressesNested(-1, item);
  }
  public AddressesNested<A> setNewAddressLike(int index,Addressable item) {
    return new AddressesNested(index, item);
  }
  public AddressesNested<A> editAddress(int index) {
    if (addresses.size() <= index) throw new RuntimeException("Can't edit addresses. Index exceeds size.");
    return setNewAddressLike(index, buildAddress(index));
  }
  public AddressesNested<A> editFirstAddress() {
    if (addresses.size() == 0) throw new RuntimeException("Can't edit first addresses. The list is empty.");
    return setNewAddressLike(0, buildAddress(0));
  }
  public AddressesNested<A> editLastAddress() {
    int index = addresses.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last addresses. The list is empty.");
    return setNewAddressLike(index, buildAddress(index));
  }
  public AddressesNested<A> editMatchingAddress(Predicate<AddressableBuilder> predicate) {
    int index = -1;
    for (int i=0;i<addresses.size();i++) { 
    if (predicate.test(addresses.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching addresses. No match found.");
    return setNewAddressLike(index, buildAddress(index));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AddressStatusFluent that = (AddressStatusFluent) o;
    if (!java.util.Objects.equals(address, that.address)) return false;

    if (!java.util.Objects.equals(addresses, that.addresses)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(address,  addresses,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (address != null) { sb.append("address:"); sb.append(address + ","); }
    if (addresses != null && !addresses.isEmpty()) { sb.append("addresses:"); sb.append(addresses); }
    sb.append("}");
    return sb.toString();
  }
  public class AddressNested<N> extends AddressableFluent<AddressNested<N>> implements Nested<N>{
    AddressNested(Addressable item) {
      this.builder = new AddressableBuilder(this, item);
    }
    AddressableBuilder builder;
    public N and() {
      return (N) AddressStatusFluent.this.withAddress(builder.build());
    }
    public N endAddress() {
      return and();
    }
    
  }
  public class AddressesNested<N> extends AddressableFluent<AddressesNested<N>> implements Nested<N>{
    AddressesNested(int index,Addressable item) {
      this.index = index;
      this.builder = new AddressableBuilder(this, item);
    }
    AddressableBuilder builder;
    int index;
    public N and() {
      return (N) AddressStatusFluent.this.setToAddresses(index,builder.build());
    }
    public N endAddress() {
      return and();
    }
    
  }
  
}

==> knative-model-6.9.0-sources.jar: io/fabric8/knative/internal/pkg/apis/duck/v1/AddressStatusFluent.java <==
package io.fabric8.knative.internal.pkg.apis.duck.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AddressStatusFluent<A extends AddressStatusFluent<A>> extends BaseFluent<A>{
  public AddressStatusFluent() {
  }
  
  public AddressStatusFluent(AddressStatus instance) {
    this.copyInstance(instance);
  }
  private AddressableBuilder address;
  private ArrayList<AddressableBuilder> addresses = new ArrayList<AddressableBuilder>();
  
  protected void copyInstance(AddressStatus instance) {
    instance = (instance != null ? instance : new AddressStatus());
  
    if (instance != null) {
        this.withAddress(instance.getAddress());
        this.withAddresses(instance.getAddresses());
        this.withAddress(instance.getAddress());
        this.withAddresses(instance.getAddresses());
      }
  }
  
  public Addressable buildAddress() {
    return this.address!=null ?this.address.build():null;
  }
  
  public A withAddress(Addressable address) {
    _visitables.get("address").remove(this.address);
    if (address!=null){ this.address= new AddressableBuilder(address); _visitables.get("address").add(this.address);} else { this.address = null; _visitables.get("address").remove(this.address); } return (A) this;
  }
  
  public boolean hasAddress() {
    return this.address != null;
  }
  
  public A withNewAddress(String cACerts,String name,String url) {
    return (A)withAddress(new Addressable(cACerts, name, url));
  }
  
  public AddressNested<A> withNewAddress() {
    return new AddressNested(null);
  }
  
  public AddressNested<A> withNewAddressLike(Addressable item) {
    return new AddressNested(item);
  }
  
  public AddressNested<A> editAddress() {
    return withNewAddressLike(java.util.Optional.ofNullable(buildAddress()).orElse(null));
  }
  
  public AddressNested<A> editOrNewAddress() {
    return withNewAddressLike(java.util.Optional.ofNullable(buildAddress()).orElse(new AddressableBuilder().build()));
  }
  
  public AddressNested<A> editOrNewAddressLike(Addressable item) {
    return withNewAddressLike(java.util.Optional.ofNullable(buildAddress()).orElse(item));
  }
  
  public A addToAddresses(int index,Addressable item) {
    if (this.addresses == null) {this.addresses = new ArrayList<AddressableBuilder>();}
    AddressableBuilder builder = new AddressableBuilder(item);
    if (index < 0 || index >= addresses.size()) { _visitables.get("addresses").add(builder); addresses.add(builder); } else { _visitables.get("addresses").add(index, builder); addresses.add(index, builder);}
    return (A)this;
  }
  
  public A setToAddresses(int index,Addressable item) {
    if (this.addresses == null) {this.addresses = new ArrayList<AddressableBuilder>();}
    AddressableBuilder builder = new AddressableBuilder(item);
    if (index < 0 || index >= addresses.size()) { _visitables.get("addresses").add(builder); addresses.add(builder); } else { _visitables.get("addresses").set(index, builder); addresses.set(index, builder);}
    return (A)this;
  }
  
  public A addToAddresses(io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable... items) {
    if (this.addresses == null) {this.addresses = new ArrayList<AddressableBuilder>();}
    for (Addressable item : items) {AddressableBuilder builder = new AddressableBuilder(item);_visitables.get("addresses").add(builder);this.addresses.add(builder);} return (A)this;
  }
  
  public A addAllToAddresses(Collection<Addressable> items) {
    if (this.addresses == null) {this.addresses = new ArrayList<AddressableBuilder>();}
    for (Addressable item : items) {AddressableBuilder builder = new AddressableBuilder(item);_visitables.get("addresses").add(builder);this.addresses.add(builder);} return (A)this;
  }
  
  public A removeFromAddresses(io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable... items) {
    if (this.addresses == null) return (A)this;
    for (Addressable item : items) {AddressableBuilder builder = new AddressableBuilder(item);_visitables.get("addresses").remove(builder); this.addresses.remove(builder);} return (A)this;
  }
  
  public A removeAllFromAddresses(Collection<Addressable> items) {
    if (this.addresses == null) return (A)this;
    for (Addressable item : items) {AddressableBuilder builder = new AddressableBuilder(item);_visitables.get("addresses").remove(builder); this.addresses.remove(builder);} return (A)this;
  }
  
  public A removeMatchingFromAddresses(Predicate<AddressableBuilder> predicate) {
    if (addresses == null) return (A) this;
    final Iterator<AddressableBuilder> each = addresses.iterator();
    final List visitables = _visitables.get("addresses");
    while (each.hasNext()) {
      AddressableBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  public List<Addressable> buildAddresses() {
    return addresses != null ? build(addresses) : null;
  }
  
  public Addressable buildAddress(int index) {
    return this.addresses.get(index).build();
  }
  
  public Addressable buildFirstAddress() {
    return this.addresses.get(0).build();
  }
  
  public Addressable buildLastAddress() {
    return this.addresses.get(addresses.size() - 1).build();
  }
  
  public Addressable buildMatchingAddress(Predicate<AddressableBuilder> predicate) {
    for (AddressableBuilder item: addresses) { if(predicate.test(item)){ return item.build();} } return null;
  }
  
  public boolean hasMatchingAddress(Predicate<AddressableBuilder> predicate) {
    for (AddressableBuilder item: addresses) { if(predicate.test(item)){ return true;} } return false;
  }
  
  public A withAddresses(List<Addressable> addresses) {
    if (this.addresses != null) { _visitables.get("addresses").clear();}
    if (addresses != null) {this.addresses = new ArrayList(); for (Addressable item : addresses){this.addToAddresses(item);}} else { this.addresses = null;} return (A) this;
  }
  
  public A withAddresses(io.fabric8.knative.internal.pkg.apis.duck.v1.Addressable... addresses) {
    if (this.addresses != null) {this.addresses.clear(); _visitables.remove("addresses"); }
    if (addresses != null) {for (Addressable item :addresses){ this.addToAddresses(item);}} return (A) this;
  }
  
  public boolean hasAddresses() {
    return addresses != null && !addresses.isEmpty();
  }
  
  public A addNewAddress(String cACerts,String name,String url) {
    return (A)addToAddresses(new Addressable(cACerts, name, url));
  }
  
  public AddressesNested<A> addNewAddress() {
    return new AddressesNested(-1, null);
  }
  
  public AddressesNested<A> addNewAddressLike(Addressable item) {
    return new AddressesNested(-1, item);
  }
  
  public AddressesNested<A> setNewAddressLike(int index,Addressable item) {
    return new AddressesNested(index, item);
  }
  
  public AddressesNested<A> editAddress(int index) {
    if (addresses.size() <= index) throw new RuntimeException("Can't edit addresses. Index exceeds size.");
    return setNewAddressLike(index, buildAddress(index));
  }
  
  public AddressesNested<A> editFirstAddress() {
    if (addresses.size() == 0) throw new RuntimeException("Can't edit first addresses. The list is empty.");
    return setNewAddressLike(0, buildAddress(0));
  }
  
  public AddressesNested<A> editLastAddress() {
    int index = addresses.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last addresses. The list is empty.");
    return setNewAddressLike(index, buildAddress(index));
  }
  
  public AddressesNested<A> editMatchingAddress(Predicate<AddressableBuilder> predicate) {
    int index = -1;
    for (int i=0;i<addresses.size();i++) { 
    if (predicate.test(addresses.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching addresses. No match found.");
    return setNewAddressLike(index, buildAddress(index));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AddressStatusFluent that = (AddressStatusFluent) o;
    if (!java.util.Objects.equals(address, that.address)) return false;
  
    if (!java.util.Objects.equals(addresses, that.addresses)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(address,  addresses,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (address != null) { sb.append("address:"); sb.append(address + ","); }
    if (addresses != null && !addresses.isEmpty()) { sb.append("addresses:"); sb.append(addresses); }
    sb.append("}");
    return sb.toString();
  }
  public class AddressNested<N> extends AddressableFluent<AddressNested<N>> implements Nested<N>{
    AddressNested(Addressable item) {
      this.builder = new AddressableBuilder(this, item);
    }
    AddressableBuilder builder;
    
    public N and() {
      return (N) AddressStatusFluent.this.withAddress(builder.build());
    }
    
    public N endAddress() {
      return and();
    }
    
  
  }
  public class AddressesNested<N> extends AddressableFluent<AddressesNested<N>> implements Nested<N>{
    AddressesNested(int index,Addressable item) {
      this.index = index;
      this.builder = new AddressableBuilder(this, item);
    }
    AddressableBuilder builder;
    int index;
    
    public N and() {
      return (N) AddressStatusFluent.this.setToAddresses(index,builder.build());
    }
    
    public N endAddress() {
      return and();
    }
    
  
  }

}
